==> qtjambi-multimedia-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiMultimedia/QAudio_shell.cpp <==
#include <QtCore/QtGlobal>
#include <qaudio.h>
#include <QtCore/QVariant>
#include <QtMultimedia/qaudio.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QAudio::convertVolume(qreal,QAudio::VolumeScale,QAudio::VolumeScale)
extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QAudio_convertVolume_1native_1qreal_1QAudio_1VolumeScale_1QAudio_1VolumeScale__DII)
(JNIEnv *__jni_env,
 jclass,
 jdouble volume0,
 jint from1,
 jint to2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAudio::convertVolume(qreal,QAudio::VolumeScale,QAudio::VolumeScale)")
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        QAudio::VolumeScale __qt_from1 = qtjambi_cast<QAudio::VolumeScale>(__jni_env, from1);
        QAudio::VolumeScale __qt_to2 = qtjambi_cast<QAudio::VolumeScale>(__jni_env, to2);
        qreal __qt_return_value = QAudio::convertVolume(static_cast<qreal>(volume0), QAudio::VolumeScale(__qt_from1), QAudio::VolumeScale(__qt_to2));
        __java_return_value = jdouble(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QAudio(){
    using namespace RegistryAPI;
    registerNamespaceTypeInfo("QAudio", "io/qt/multimedia/QAudio", nullptr);

// BEGIN: enums and flags
    registerEnumTypeInfo<QAudio::Error>("QAudio::Error", "io/qt/multimedia/QAudio$Error");
    registerEnumTypeInfo<QAudio::Mode>("QAudio::Mode", "io/qt/multimedia/QAudio$Mode");
    registerEnumTypeInfo<QAudio::Role>("QAudio::Role", "io/qt/multimedia/QAudio$Role");
    registerEnumTypeInfo<QAudio::State>("QAudio::State", "io/qt/multimedia/QAudio$State");
    registerEnumTypeInfo<QAudio::VolumeScale>("QAudio::VolumeScale", "io/qt/multimedia/QAudio$VolumeScale");
// END: enums and flags
}

==> qtjambi-multimedia-debuginfo-linux-x64-6.6.0.jar: sources/QtJambiMultimedia/QAudio_shell.cpp <==
#include <QtCore/QtGlobal>
#include <qaudio.h>
#include <QtCore/QVariant>
#include <QtMultimedia/qaudio.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QAudio::convertVolume(float,QAudio::VolumeScale,QAudio::VolumeScale)
extern "C" Q_DECL_EXPORT jfloat JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QAudio_convertVolume_1native_1float_1QAudio_1VolumeScale_1QAudio_1VolumeScale__FII)
(JNIEnv *__jni_env,
 jclass,
 jfloat volume0,
 jint from1,
 jint to2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAudio::convertVolume(float,QAudio::VolumeScale,QAudio::VolumeScale)")
    jfloat __java_return_value{0};
    QTJAMBI_TRY {
        QAudio::VolumeScale __qt_from1 = qtjambi_cast<QAudio::VolumeScale>(__jni_env, from1);
        QAudio::VolumeScale __qt_to2 = qtjambi_cast<QAudio::VolumeScale>(__jni_env, to2);
        __java_return_value = QAudio::convertVolume(static_cast<float>(volume0), QAudio::VolumeScale(__qt_from1), QAudio::VolumeScale(__qt_to2));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QAudio(){
    using namespace RegistryAPI;
    registerNamespaceTypeInfo("QAudio", "io/qt/multimedia/QAudio", nullptr);

// BEGIN: enums and flags
    registerEnumTypeInfo<QAudio::Error>("QAudio::Error", "io/qt/multimedia/QAudio$Error");
    registerEnumTypeInfo<QAudio::State>("QAudio::State", "io/qt/multimedia/QAudio$State");
    registerEnumTypeInfo<QAudio::VolumeScale>("QAudio::VolumeScale", "io/qt/multimedia/QAudio$VolumeScale");
// END: enums and flags
}
